package main

import (
	"dorisbot/models"
	discordmodel "dorisbot/models/discord"
	"dorisbot/pkg/config"
	"dorisbot/pkg/options"
	"dorisbot/pkg/svc/discord"
	"fmt"
	"log"

	"git.trj.tw/golang/utils"
)

func init() {
	options.RegOptions()
}

func main() {
	var err error
	opts := options.GetOptions()
	if opts.Help {
		opts.ShowUsage()
		return
	}

	fmt.Println("Bot Svc")
	cc := make(chan bool)

	err = config.LoadConfig(opts.Config)
	if err != nil {
		log.Fatal(err)
	}

	conf := config.GetConfig()

	client, err := discord.NewClient(conf.Discord.BotToken)
	if err != nil {
		log.Fatal(err)
	}

	err = client.Connect()
	if err != nil {
		log.Fatal(err)
	}
	defer client.Close()

	_, err = models.NewDB(conf.Database)
	if err != nil {
		log.Fatal(err)
	}

	list, err := discordmodel.GetDiscordServerList()
	if err != nil {
		log.Fatal(err)
	}
	log.Println("server list ::: ", list)
	for _, it := range list {
		log.Println(utils.ToMap(it))
	}

	<-cc
}
